import { __decorate, __metadata } from 'tslib';
import { Input, Component, Pipe, NgModule } from '@angular/core';
import { CommonModule } from '@angular/common';
import { MatIconModule, MatListModule, MatInputModule, MatCardModule } from '@angular/material';
import { FormsModule } from '@angular/forms';
import { NgxPaginationModule } from 'ngx-pagination';
import { FlexLayoutModule } from '@angular/flex-layout';

let CommandComponent = class CommandComponent {
    constructor() {
        // @Output() command = new EventEmitter<ICommand>();
        this.title = 'List of Commands';
        this.currentPageNumber = 1;
        this.searchTerm = '';
    }
    ngOnInit() {
    }
};
__decorate([
    Input(),
    __metadata("design:type", Array)
], CommandComponent.prototype, "commands", void 0);
CommandComponent = __decorate([
    Component({
        selector: 'app-command',
        template: "<div class=\"list-page-container\">\n    <div class=\"list-header\">\n        <h2 mat-subheader>{{title}}</h2>\n        <!-- <h2 class=\"mat-display-1\">{{title}}</h2> -->\n    </div>\n    <div class=\"inputcont\">\n        <form class=\"search-form\">\n            <i matPrefix class=\"material-icons\">\n                search\n            </i>\n            <mat-form-field class=\"input-full-width\">\n\n                <input matInput placeholder=\"Search Command\" value=\"\" [(ngModel)]=\"searchTerm\" name=\"name\">\n            </mat-form-field>\n        </form>\n    </div>\n\n    <div fxLayout=\"row wrap\" fxLayout.xs=\"column\">\n        <div *ngFor=\"let command of commands \n    | commandFilter : searchTerm \n    | paginate: { itemsPerPage: 8, currentPage: currentPageNumber }\" fxFlex=\"25\" fxFlex.md=\"33\" fxFlex.sm=\"50\"\n            fxFlex.xs=\"50\" fxLayout=\"column\" style=\"padding: 2%;\">\n            <div>\n                <mat-card class=\"my-card\">\n                    <mat-card-header>\n                        <mat-icon mat-card-avatar *ngIf=\"command.status==='active'\" class=\"active-status\">lens\n                        </mat-icon>\n                        <mat-icon mat-card-avatar *ngIf=\"command.status==='inactive'\" class=\"inactive-status\">lens\n                        </mat-icon>\n                        <mat-card-title class=\"\">{{command.name}}</mat-card-title>\n                        <mat-card-subtitle>{{command.description}}</mat-card-subtitle>\n                    </mat-card-header>\n\n                    <mat-card-content>\n                        <div *ngIf=\"command.parameterList\">\n                            <h3 class=\"mat-h3\">Parameters:</h3>\n                        </div>\n\n                        <p *ngFor=\"let parameter of command.parameterList; let i = index\">{{i+1}}.\n                            {{parameter.parameterName}},\n                            Description:\n                            {{parameter.parameterDesciption}}</p>\n                        <div *ngIf=\"command.tags\">\n                            <h3 class=\"mat-h3\">Tags: <span class=\"mat-body\">{{command.tags}}</span></h3>\n                        </div>\n                        <div *ngIf=\"command.usage\">\n                            <h3 class=\"mat-h3\">Usage: <span class=\"mat-body\">{{command.usage}}</span></h3>\n                        </div>\n                    </mat-card-content>\n                </mat-card>\n            </div>\n        </div>\n    </div>\n\n    <!-- <mat-nav-list class=\"mat-list\">\n        <mat-list-item (click)=\"onSelectCommand(command)\" *ngFor=\"let command of commands | commandFilter : searchTerm | paginate: { itemsPerPage: 3, currentPage: currentPageNumber, totalItems: commands.length }\">\n            <mat-icon mat-list-icon *ngIf=\"command.status==='active'\" class=\"active-status\">lens</mat-icon>\n            <mat-icon mat-list-icon *ngIf=\"command.status==='inactive'\" class=\"inactive-status\">lens</mat-icon>\n            <h4 mat-line>{{command.name}}</h4>\n            <p mat-line> {{command.desc}} </p>\n        </mat-list-item>\n    </mat-nav-list> -->\n\n</div>\n<div class=\"pagination-control\">\n    <pagination-controls (pageChange)=\"currentPageNumber = $event\" responsive=\"true\"></pagination-controls>\n</div>",
        styles: [".inputcont{width:100%;text-align:center;margin:0 auto}.search-form{width:100%;text-align:center}.input-full-width{width:80%;padding-left:5px}.active-status{color:rgba(18,129,3,.54)}.inactive-status{color:rgba(123,128,123,.54)}.mat-list{margin:0 auto;width:80%}pagination-controls{text-align:center;position:relative;bottom:5px;width:100%}.my-card{min-width:250px;height:300px;background-color:#f5f5f5}.example-header-image{background-size:cover}.wrapper1{display:-ms-grid;display:grid;grid-template-columns:repeat(auto-fit,minmax(320px,1fr));grid-column-gap:1em;grid-row-gap:1em;padding:30px 20px}"]
    }),
    __metadata("design:paramtypes", [])
], CommandComponent);

let CommandFilterPipe = class CommandFilterPipe {
    transform(commands, searchTerm) {
        if (!commands || !searchTerm) {
            return commands;
        }
        return commands.filter(command => command.name.toLowerCase().indexOf(searchTerm.toLowerCase()) !== -1);
    }
};
CommandFilterPipe = __decorate([
    Pipe({
        name: 'commandFilter'
    })
], CommandFilterPipe);

let CommandModule = class CommandModule {
};
CommandModule = __decorate([
    NgModule({
        declarations: [CommandComponent, CommandFilterPipe],
        imports: [
            CommonModule,
            MatIconModule,
            MatListModule,
            MatInputModule,
            FormsModule,
            NgxPaginationModule,
            MatCardModule,
            FlexLayoutModule
        ],
        exports: [
            CommandComponent
        ]
    })
], CommandModule);

/**
 * Generated bundle index. Do not edit.
 */

export { CommandModule, CommandComponent as ɵa, CommandFilterPipe as ɵb };
//# sourceMappingURL=my-command-library.js.map
